@@ -29,7 +29,7 @@ sub BUILD ( $self, $args ) {
         }
     );
 
-    my $dbname = $self->uri->path || ':memory:';
+    my $dbname = $self->uri->path->to_string || ':memory:';
 
     $self->{_dbh} = DBI->connect( "dbi:SQLite:dbname=$dbname", q[], q[], $attr );
 
